[][src]Struct hyperbole::tree::PathSpec

#[repr(C)]pub struct PathSpec<P> { /* fields omitted */ }

A uri specification and well-typed parameter parser.

See the path! macro for usage details.

Implementations

impl PathSpec<HNil>[src]

pub const ROOT: Self[src]

The root path.

impl<P> PathSpec<P>[src]

pub fn segment(self, name: &'static str) -> Self[src]

Append a static segment to this spec.

Panics

This panics if the segment contains /, or if the path spec already contains a catch-all parameter.

pub fn dynamic<T: FromStr>(
    self,
    name: &'static str
) -> PathSpec<<P as Add<HCons<T, HNil>>>::Output> where
    P: Add<HCons<T, HNil>>, 
[src]

Append a dynamic path parameter of type T to this spec.

Panics

This panics if the path spec already contains a catch-all parameter.

pub fn catch_all<T: FromStr>(
    self,
    name: &'static str
) -> PathSpec<<P as Add<HCons<T, HNil>>>::Output> where
    P: Add<HCons<T, HNil>>, 
[src]

Append a catch-all path parameter of type T to this spec.

Panics

This panics if the path spec already contains a catch-all parameter.

pub fn query<T: FromStr>(
    self,
    name: &'static str
) -> PathSpec<<P as Add<HCons<T, HNil>>>::Output> where
    P: Add<HCons<T, HNil>>, 
[src]

Add a query parameter of type T to this spec.

Panics

This panics if the path spec already contains a query parameter with the same name.